diff --git a/dumux/material/fluidsystems/1pgas.hh b/dumux/material/fluidsystems/1pgas.hh
index e5fa4dc2a276f481c59928e298965b3b27fc1218..ef8a86ac5ee1a43d3e929e90b034d17ee00e5332 100644
--- a/dumux/material/fluidsystems/1pgas.hh
+++ b/dumux/material/fluidsystems/1pgas.hh
@@ -74,7 +74,7 @@ public:
      * \param phaseIdx The index of the fluid phase to consider
      */
     static std::string phaseName(int phaseIdx = 0)
-    { return IOName::gaseous(); }
+    { return IOName::gaseousPhase(); }
 
     /*!
      * \brief A human readable name for the component.
diff --git a/dumux/material/fluidsystems/1pliquid.hh b/dumux/material/fluidsystems/1pliquid.hh
index d7f4bbf30e9ccced66c522c163f64620b0cd1769..a4b818749dd5813c633025fde6140a32ef2de029 100644
--- a/dumux/material/fluidsystems/1pliquid.hh
+++ b/dumux/material/fluidsystems/1pliquid.hh
@@ -74,7 +74,7 @@ public:
      * \param phaseIdx The index of the fluid phase to consider
      */
     static std::string phaseName(int phaseIdx = 0)
-    { return IOName::liquid(); }
+    { return IOName::liquidPhase(); }
 
     /*!
      * \brief A human readable name for the component.
diff --git a/dumux/material/fluidsystems/2p1c.hh b/dumux/material/fluidsystems/2p1c.hh
index 4bfe614d72b0b193c251d7b11fd3990e48afd154..c2ccdfe78fcce1330a7c2e791ff6d721bb32facb 100644
--- a/dumux/material/fluidsystems/2p1c.hh
+++ b/dumux/material/fluidsystems/2p1c.hh
@@ -70,8 +70,8 @@ public:
     static std::string phaseName(int phaseIdx)
     {
         static std::string name[] = {
-            std::string(IOName::liquid()),
-            std::string(IOName::gaseous()),
+            std::string(IOName::liquidPhase()),
+            std::string(IOName::gaseousPhase()),
         };
 
         assert(0 <= phaseIdx && phaseIdx < numPhases);
diff --git a/dumux/material/fluidsystems/2pimmiscible.hh b/dumux/material/fluidsystems/2pimmiscible.hh
index f6cc03cf975b2a867ec0f94caf25fb2c57bf1af5..43e96ecea9e5c74499747be43994f99d3af5e9d1 100644
--- a/dumux/material/fluidsystems/2pimmiscible.hh
+++ b/dumux/material/fluidsystems/2pimmiscible.hh
@@ -90,16 +90,16 @@ public:
         if (!Fluid0::isGas() && !Fluid1::isGas())
         {
             if (phaseIdx == phase0Idx)
-                return Components::IsAqueous<typename Fluid0::Component>::value ? IOName::aqueous() : IOName::napl();
+                return Components::IsAqueous<typename Fluid0::Component>::value ? IOName::aqueousPhase() : IOName::naplPhase();
             else
-                return Components::IsAqueous<typename Fluid1::Component>::value ? IOName::aqueous() : IOName::napl();
+                return Components::IsAqueous<typename Fluid1::Component>::value ? IOName::aqueousPhase() : IOName::naplPhase();
         }
         else
         {
             if (phaseIdx == phase0Idx)
-                return Fluid0::isGas() ? IOName::gaseous() : IOName::liquid();
+                return Fluid0::isGas() ? IOName::gaseousPhase() : IOName::liquidPhase();
             else
-                return Fluid1::isGas() ? IOName::gaseous() : IOName::liquid();
+                return Fluid1::isGas() ? IOName::gaseousPhase() : IOName::liquidPhase();
         }
     }
 
diff --git a/dumux/material/fluidsystems/3pimmiscible.hh b/dumux/material/fluidsystems/3pimmiscible.hh
index 88d9eb94c696ed4edba38caf58c35aa124d2a8b1..885f34022d367bd9aeaf706c300f91c514cd5f20 100644
--- a/dumux/material/fluidsystems/3pimmiscible.hh
+++ b/dumux/material/fluidsystems/3pimmiscible.hh
@@ -94,10 +94,10 @@ public:
         switch (phaseIdx)
         {
             case wPhaseIdx: return Components::IsAqueous<typename WettingFluid::Component>::value
-                            ? IOName::aqueous() : IOName::napl();
+                            ? IOName::aqueousPhase() : IOName::naplPhase();
             case nPhaseIdx: return Components::IsAqueous<typename NonwettingFluid::Component>::value
-                            ? IOName::aqueous() : IOName::napl();
-            case gPhaseIdx: return IOName::gaseous();
+                            ? IOName::aqueousPhase() : IOName::naplPhase();
+            case gPhaseIdx: return IOName::gaseousPhase();
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/dumux/material/fluidsystems/brine.hh b/dumux/material/fluidsystems/brine.hh
index c1d04a7d5f6fd518d655e7522266c7b78394f4b1..67685a187ebcdaa5cbda4d6bd7c4c8b2d739c3db 100644
--- a/dumux/material/fluidsystems/brine.hh
+++ b/dumux/material/fluidsystems/brine.hh
@@ -71,7 +71,7 @@ public:
     static const std::string phaseName(int phaseIdx = liquidPhaseIdx)
     {
         assert(phaseIdx == liquidPhaseIdx);
-        return IOName::liquid();
+        return IOName::liquidPhase();
     }
 
     /*!
diff --git a/dumux/material/fluidsystems/brineair.hh b/dumux/material/fluidsystems/brineair.hh
index 24cda87536935aa2dcbd37ab90c51498a79ed172..65f96a9dbc997b3ea86ec73284b389b0657955e4 100644
--- a/dumux/material/fluidsystems/brineair.hh
+++ b/dumux/material/fluidsystems/brineair.hh
@@ -150,8 +150,8 @@ public:
         assert(0 <= phaseIdx && phaseIdx < numPhases);
         switch (phaseIdx)
         {
-            case liquidPhaseIdx: return IOName::liquid();
-            case gasPhaseIdx: return IOName::gaseous();
+            case liquidPhaseIdx: return IOName::liquidPhase();
+            case gasPhaseIdx: return IOName::gaseousPhase();
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/dumux/material/fluidsystems/brineco2.hh b/dumux/material/fluidsystems/brineco2.hh
index 489c384c468177a28dfacc2a8181095673723296..17b5e215e3ce2a95f0df420f64e180f83eec61a5 100644
--- a/dumux/material/fluidsystems/brineco2.hh
+++ b/dumux/material/fluidsystems/brineco2.hh
@@ -197,8 +197,8 @@ public:
     {
         switch (phaseIdx)
         {
-            case liquidPhaseIdx: return IOName::liquid();
-            case gasPhaseIdx: return IOName::gaseous();
+            case liquidPhaseIdx: return IOName::liquidPhase();
+            case gasPhaseIdx: return IOName::gaseousPhase();
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/dumux/material/fluidsystems/h2oair.hh b/dumux/material/fluidsystems/h2oair.hh
index 9cc3091bb9364e16630c023837537f6c353e8e89..438eb7f2d588241c3e6b4c74a38ccc3f5c188ca4 100644
--- a/dumux/material/fluidsystems/h2oair.hh
+++ b/dumux/material/fluidsystems/h2oair.hh
@@ -106,8 +106,8 @@ public:
         assert(0 <= phaseIdx && phaseIdx < numPhases);
         switch (phaseIdx)
         {
-            case liquidPhaseIdx: return IOName::liquid();
-            case gasPhaseIdx: return IOName::gaseous();
+            case liquidPhaseIdx: return IOName::liquidPhase();
+            case gasPhaseIdx: return IOName::gaseousPhase();
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/dumux/material/fluidsystems/h2oairmesitylene.hh b/dumux/material/fluidsystems/h2oairmesitylene.hh
index 9c8a74049a33f8155197be86faae37b151dfc1da..d5dafd18bff6b4e951410a8a021070c37958563a 100644
--- a/dumux/material/fluidsystems/h2oairmesitylene.hh
+++ b/dumux/material/fluidsystems/h2oairmesitylene.hh
@@ -199,9 +199,9 @@ public:
         assert(0 <= phaseIdx && phaseIdx < numPhases);
         switch (phaseIdx)
         {
-            case wPhaseIdx: return IOName::aqueous();
-            case nPhaseIdx: return IOName::napl();
-            case gPhaseIdx: return IOName::gaseous();
+            case wPhaseIdx: return IOName::aqueousPhase();
+            case nPhaseIdx: return IOName::naplPhase();
+            case gPhaseIdx: return IOName::gaseousPhase();
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/dumux/material/fluidsystems/h2oairxylene.hh b/dumux/material/fluidsystems/h2oairxylene.hh
index f9832c0b18befd3c190a5a2073eed5f6a280af3e..9fd072be019d15883fb1aa92e599d85cdc7b0227 100644
--- a/dumux/material/fluidsystems/h2oairxylene.hh
+++ b/dumux/material/fluidsystems/h2oairxylene.hh
@@ -200,9 +200,9 @@ public:
         assert(0 <= phaseIdx && phaseIdx < numPhases);
         switch (phaseIdx)
         {
-            case wPhaseIdx: return IOName::aqueous();
-            case nPhaseIdx: return IOName::napl();
-            case gPhaseIdx: return IOName::gaseous();
+            case wPhaseIdx: return IOName::aqueousPhase();
+            case nPhaseIdx: return IOName::naplPhase();
+            case gPhaseIdx: return IOName::gaseousPhase();
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/dumux/material/fluidsystems/h2oheavyoil.hh b/dumux/material/fluidsystems/h2oheavyoil.hh
index 55f7c00c477aa66f159840154e812c786e94b070..b4e1b3437ea6c209361bdf134d6a8eea5429b271 100644
--- a/dumux/material/fluidsystems/h2oheavyoil.hh
+++ b/dumux/material/fluidsystems/h2oheavyoil.hh
@@ -189,9 +189,9 @@ public:
         assert(0 <= phaseIdx && phaseIdx < numPhases);
         switch (phaseIdx)
         {
-            case wPhaseIdx: return IOName::aqueous();
-            case nPhaseIdx: return IOName::napl();
-            case gPhaseIdx: return IOName::gaseous();
+            case wPhaseIdx: return IOName::aqueousPhase();
+            case nPhaseIdx: return IOName::naplPhase();
+            case gPhaseIdx: return IOName::gaseousPhase();
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/dumux/material/fluidsystems/h2on2.hh b/dumux/material/fluidsystems/h2on2.hh
index f1cf83305c70c2b99279228d701295ed3e39e717..47d8f04e78261544d04d72eb0ff02c2bc024134e 100644
--- a/dumux/material/fluidsystems/h2on2.hh
+++ b/dumux/material/fluidsystems/h2on2.hh
@@ -107,8 +107,8 @@ public:
         assert(0 <= phaseIdx && phaseIdx < numPhases);
         switch (phaseIdx)
         {
-            case liquidPhaseIdx: return IOName::liquid();
-            case gasPhaseIdx: return IOName::gaseous();
+            case liquidPhaseIdx: return IOName::liquidPhase();
+            case gasPhaseIdx: return IOName::gaseousPhase();
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/dumux/material/fluidsystems/h2on2o2.hh b/dumux/material/fluidsystems/h2on2o2.hh
index c30a26d4d7c803a2183581ad03965d86369a3846..9673b9b904b94afb92a21cd8ea63ebe3f73dddd4 100644
--- a/dumux/material/fluidsystems/h2on2o2.hh
+++ b/dumux/material/fluidsystems/h2on2o2.hh
@@ -126,8 +126,8 @@ public:
         assert(0 <= phaseIdx && phaseIdx < numPhases);
         switch (phaseIdx)
         {
-            case liquidPhaseIdx: return IOName::liquid();
-            case gasPhaseIdx: return IOName::gaseous();
+            case liquidPhaseIdx: return IOName::liquidPhase();
+            case gasPhaseIdx: return IOName::gaseousPhase();
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/dumux/material/fluidsystems/liquidphase2c.hh b/dumux/material/fluidsystems/liquidphase2c.hh
index c0e0d9a751915c478aaf0b73282beab5d92b8e47..a911e6c426bc0feac2544f9719c04b63ae2029c8 100644
--- a/dumux/material/fluidsystems/liquidphase2c.hh
+++ b/dumux/material/fluidsystems/liquidphase2c.hh
@@ -76,7 +76,7 @@ public:
      * \param phaseIdx The index of the fluid phase to consider
      */
     static std::string phaseName(int phaseIdx = 0)
-    { return IOName::liquid(); }
+    { return IOName::liquidPhase(); }
 
     /*!
      * \brief Returns whether the fluids are miscible
diff --git a/dumux/material/fluidsystems/spe5.hh b/dumux/material/fluidsystems/spe5.hh
index eaafbb876931128248dc14e9b98c6ade0caf8b85..d68745b9bdff8d17ed1c43cbe22563ef69b2f30c 100644
--- a/dumux/material/fluidsystems/spe5.hh
+++ b/dumux/material/fluidsystems/spe5.hh
@@ -90,9 +90,9 @@ public:
         assert(0 <= phaseIdx && phaseIdx < numPhases);
         switch (phaseIdx)
         {
-            case gPhaseIdx: return IOName::gaseous();
-            case wPhaseIdx: return IOName::aqueous();
-            case oPhaseIdx: return IOName::napl();
+            case gPhaseIdx: return IOName::gaseousPhase();
+            case wPhaseIdx: return IOName::aqueousPhase();
+            case oPhaseIdx: return IOName::naplPhase();
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/dumux/porousmediumflow/richardsnc/iofields.hh b/dumux/porousmediumflow/richardsnc/iofields.hh
index 99c20395d6b143284c4f98443b4ee7061571a491..865623ad384a80fc879a915fedf087e68547c500 100644
--- a/dumux/porousmediumflow/richardsnc/iofields.hh
+++ b/dumux/porousmediumflow/richardsnc/iofields.hh
@@ -43,21 +43,21 @@ public:
         using FS = typename VolumeVariables::FluidSystem;
 
         out.addVolumeVariable([](const auto& v){ return v.saturation(VolumeVariables::liquidPhaseIdx); },
-                              IOName::saturation() + "_" + IOName::liquid());
+                              IOName::saturation() + "_" + IOName::liquidPhase());
         out.addVolumeVariable([](const auto& v){ return v.saturation(VolumeVariables::gasPhaseIdx); },
-                              IOName::saturation() + "_" + IOName::gaseous());
+                              IOName::saturation() + "_" + IOName::gaseousPhase());
         out.addVolumeVariable([](const auto& v){ return v.pressure(VolumeVariables::liquidPhaseIdx); },
-                              IOName::pressure() + "_" + IOName::liquid());
+                              IOName::pressure() + "_" + IOName::liquidPhase());
         out.addVolumeVariable([](const auto& v){ return v.pressure(VolumeVariables::gasPhaseIdx); },
-                              IOName::pressure() + "_" + IOName::gaseous());
+                              IOName::pressure() + "_" + IOName::gaseousPhase());
         out.addVolumeVariable([](const auto& v){ return v.capillaryPressure(); },
                               IOName::capillaryPressure());
         out.addVolumeVariable([](const auto& v){ return v.density(FS::liquidPhaseIdx); },
-                              IOName::density() + "_" + IOName::liquid());
+                              IOName::density() + "_" + IOName::liquidPhase());
         out.addVolumeVariable([](const auto& v){ return v.mobility(FS::liquidPhaseIdx); },
-                              IOName::mobility() + "_" + IOName::liquid());
+                              IOName::mobility() + "_" + IOName::liquidPhase());
         out.addVolumeVariable([](const auto& v){ return v.relativePermeability(VolumeVariables::liquidPhaseIdx); },
-                              IOName::relativePermeability() + "_" + IOName::liquid());
+                              IOName::relativePermeability() + "_" + IOName::liquidPhase());
         out.addVolumeVariable([](const auto& v){ return v.porosity(); },
                               IOName::porosity());
         out.addVolumeVariable([](const auto& v){ return v.temperature(); },
diff --git a/dumux/io/name.hh b/dumux/io/name.hh
index e44c7019ae6835af4249ddd71f64887c080e8eeb..340adf26127831f2b0f1ec1df3a693d6b098d8a6 100644
--- a/dumux/io/name.hh
+++ b/dumux/io/name.hh
@@ -115,20 +115,20 @@ template<class FluidSystem>
 std::string massFraction(int phaseIdx, int compIdx) noexcept
 { return "X^" + FluidSystem::componentName(compIdx) + "_" + FluidSystem::phaseName(phaseIdx); }
 
-//! I/O name of liquid
-std::string liquid() noexcept
+//! I/O name of liquid phase
+std::string liquidPhase() noexcept
 { return "liq"; }
 
-//! I/O name of gaseous
-std::string gaseous() noexcept
+//! I/O name of gaseous phase
+std::string gaseousPhase() noexcept
 { return "gas"; }
 
-//! I/O name of aqueous
-std::string aqueous() noexcept
+//! I/O name of aqueous phase
+std::string aqueousPhase() noexcept
 { return "aq"; }
 
-//! I/O name of napl
-std::string napl() noexcept
+//! I/O name of napl phase
+std::string naplPhase() noexcept
 { return "napl"; }
 
 //! I/O name of capillary pressure